@@ -11,9 +11,17 @@ use netlink_packet_utils::{
     DecodeError,
 };
 
-#[cfg(any(target_os = "linux", target_os = "fuchsia",))]
+#[cfg(any(
+    target_os = "linux",
+    target_os = "fuchsia",
+    target_os = "android"
+))]
 use super::af_spec::VecAfSpecBridge;
-#[cfg(any(target_os = "linux", target_os = "fuchsia",))]
+#[cfg(any(
+    target_os = "linux",
+    target_os = "fuchsia",
+    target_os = "android"
+))]
 use super::proto_info::VecLinkProtoInfoBridge;
 use super::{
     af_spec::VecAfSpecUnspec,
@@ -188,7 +196,7 @@ impl Nla for LinkAttribute {
             Self::IfName(string)
             | Self::Qdisc(string)
             | Self::IfAlias(string)
-            | Self::PhysPortName(string) => string.as_bytes().len() + 1,
+            | Self::PhysPortName(string) => string.len() + 1,
 
             Self::Mode(_) | Self::Carrier(_) | Self::ProtoDown(_) => 1,
 
@@ -376,14 +384,20 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
             IFLA_VFINFO_LIST => {
                 let err =
                     |payload| format!("invalid IFLA_VFINFO_LIST {payload:?}");
-                Self::VfInfoList(
-                    VecLinkVfInfo::parse(
-                        &NlaBuffer::new_checked(payload)
-                            .context(err(payload))?,
+                if !payload.is_empty() {
+                    Self::VfInfoList(
+                        VecLinkVfInfo::parse(
+                            &NlaBuffer::new_checked(payload)
+                                .context(err(payload))?,
+                        )
+                        .context(err(payload))?
+                        .0,
                     )
-                    .context(err(payload))?
-                    .0,
-                )
+                } else {
+                    // Empty IFLA_VFINFO_LIST, this is likely a netdevsim device
+                    // no need to parse it, it is empty
+                    Self::VfInfoList(vec![])
+                }
             }
             IFLA_VF_PORTS => {
                 let err =
@@ -435,7 +449,11 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
                         .context(err(payload))?
                         .0,
                     ),
-                    #[cfg(any(target_os = "linux", target_os = "fuchsia",))]
+                    #[cfg(any(
+                        target_os = "linux",
+                        target_os = "fuchsia",
+                        target_os = "android"
+                    ))]
                     AddressFamily::Bridge => Self::ProtoInfoBridge(
                         VecLinkProtoInfoBridge::parse(&NlaBuffer::new_checked(
                             payload,
@@ -447,8 +465,8 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
                     ),
                     _ => Self::ProtoInfoUnknown(
                         DefaultNla::parse(buf).context(format!(
-                            "invalid IFLA_PROTINFO for \
-                        {interface_family:?}: {payload:?}"
+                            "invalid IFLA_PROTINFO for {interface_family:?}: \
+                             {payload:?}"
                         ))?,
                     ),
                 }
@@ -596,7 +614,7 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
             ),
             IFLA_MAP => {
                 let err =
-                    |payload| format!("Invalid IFLA_MAP value {:?}", payload);
+                    |payload| format!("Invalid IFLA_MAP value {payload:?}");
                 Self::Map(
                     super::Map::parse(
                         &MapBuffer::new_checked(payload)
@@ -614,7 +632,7 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
                     )
                     .as_slice(),
                 ))
-                .context(format!("Invalid IFLA_STATS value {:?}", payload))?,
+                .context(format!("Invalid IFLA_STATS value {payload:?}"))?,
             ),
             IFLA_STATS64 => {
                 let payload = expand_buffer_if_small(
@@ -627,8 +645,7 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
                         payload.as_slice(),
                     ))
                     .context(format!(
-                        "Invalid IFLA_STATS64 value {:?}",
-                        payload
+                        "Invalid IFLA_STATS64 value {payload:?}"
                     ))?,
                 )
             }
@@ -644,7 +661,11 @@ impl<'a, T: AsRef<[u8]> + ?Sized>
                         .0,
                     )
                 }
-                #[cfg(any(target_os = "linux", target_os = "fuchsia",))]
+                #[cfg(any(
+                    target_os = "linux",
+                    target_os = "fuchsia",
+                    target_os = "android"
+                ))]
                 AddressFamily::Bridge => {
                     let err = "invalid IFLA_AF_SPEC value for AF_BRIDGE";
                     Self::AfSpecBridge(
