@@ -9,10 +9,9 @@ pub(crate) fn expand_buffer_if_small(
     match payload.len() {
         l if l > expected_size => {
             log::warn!(
-                "Specified {nla_name} NLA attribute holds \
-            more(most likely new kernel) data which is unknown to \
-            netlink-packet-route crate, expecting \
-            {expected_size}, got {}",
+                "Specified {nla_name} NLA attribute holds more(most likely \
+                 new kernel) data which is unknown to netlink-packet-route \
+                 crate, expecting {expected_size}, got {}",
                 got.len()
             );
         }
