@@ -39,17 +39,17 @@ pub use self::ext_mask::LinkExtentMask;
 pub use self::header::{LinkHeader, LinkMessageBuffer};
 pub use self::link_flag::LinkFlags;
 pub use self::link_info::{
-    BondAdInfo, BondArpValidate, BondMode, BondPortState, BridgeId,
-    BridgeIdBuffer, BridgePortMulticastRouter, BridgePortState,
-    BridgeQuerierState, GeneveDf, HsrProtocol, InfoBond, InfoBondPort,
-    InfoBridge, InfoBridgePort, InfoData, InfoGeneve, InfoGreTap, InfoGreTap6,
-    InfoGreTun, InfoGreTun6, InfoGtp, InfoHsr, InfoIpVlan, InfoIpVtap,
-    InfoIpoib, InfoKind, InfoMacSec, InfoMacVlan, InfoMacVtap, InfoPortData,
-    InfoPortKind, InfoSitTun, InfoTun, InfoVeth, InfoVlan, InfoVrf,
-    InfoVrfPort, InfoVti, InfoVxlan, InfoXfrm, IpVlanFlags, IpVlanMode,
-    IpVtapFlags, IpVtapMode, LinkInfo, LinkXstats, MacSecCipherId,
-    MacSecOffload, MacSecValidate, MacVlanMode, MacVtapMode, MiiStatus,
-    VlanQosMapping,
+    BondAdInfo, BondArpAllTargets, BondArpValidate, BondFailOverMac, BondMode,
+    BondPortState, BondXmitHashPolicy, BridgeId, BridgeIdBuffer,
+    BridgePortMulticastRouter, BridgePortState, BridgeQuerierState, GeneveDf,
+    HsrProtocol, InfoBond, InfoBondPort, InfoBridge, InfoBridgePort, InfoData,
+    InfoGeneve, InfoGreTap, InfoGreTap6, InfoGreTun, InfoGreTun6, InfoGtp,
+    InfoHsr, InfoIpVlan, InfoIpVtap, InfoIpoib, InfoKind, InfoMacSec,
+    InfoMacVlan, InfoMacVtap, InfoPortData, InfoPortKind, InfoSitTun, InfoTun,
+    InfoVeth, InfoVlan, InfoVrf, InfoVrfPort, InfoVti, InfoVxlan, InfoXfrm,
+    IpVlanFlags, IpVlanMode, IpVtapFlags, IpVtapMode, LinkInfo, LinkXstats,
+    MacSecCipherId, MacSecOffload, MacSecValidate, MacVlanMode, MacVtapMode,
+    MiiStatus, VlanQosMapping,
 };
 pub use self::link_layer_type::LinkLayerType;
 pub use self::link_state::State;
