@@ -25,8 +25,7 @@ impl<'a, T: AsRef<[u8]> + ?Sized> Parseable<NlaBuffer<&'a T>>
                 )?)?);
             } else {
                 log::warn!(
-                    "BUG: Expecting IFLA_VF_PORT in IFLA_VF_PORTS, \
-                    but got {}",
+                    "BUG: Expecting IFLA_VF_PORT in IFLA_VF_PORTS, but got {}",
                     nla.kind()
                 );
             }
